@@ -2,7 +2,7 @@ package Cairo::Install::Files;
 
 $self = {
           'deps' => [],
-          'inc' => '-I. -Ibuild -I/usr/include/cairo -I/usr/include/freetype2 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/libpng16 -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/freetype2 -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/libpng16',
+          'inc' => '-I. -Ibuild -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16',
           'libs' => '-l:libcairo.dll.a -l:libcairo.dll.a -lfreetype',
           'typemaps' => [
                           'cairo-perl-auto.typemap',
